@@ -446,6 +446,8 @@ class CurveBuilder:
         self.current_orientation = EnumToggleable(Orientation)
         self.id_provider = id_provider
 
+    def set_curve_type(self, curve_type: CurveType):
+        self.current_curve_type.set_value(curve_type)
 
     def toggle_curve_type(self):
         self.current_curve_type.toggle()
@@ -533,6 +535,10 @@ class CurveBuilder:
 
     def force_continuity(self, next_point: Vector2):
         curves = self.curves_from_points(self.current_curve_type.value, self.current_points)
+
+        if curves is None or len(curves) == 0:
+            return next_point
+
         return curves[-1].force_continuity(next_point)
 
 
